<?php
// $Id: cck_gallery.admin.inc,v 1.1.2.4 2009/06/12 16:12:13 rareface Exp $

/**
 * Build the admin settings form.
 */
include_once(drupal_get_path('module', 'views').'/includes/admin.inc');

function cck_gallery_admin_form($form_state) {
  
  //load list of views in to array for select lists
  $views = views_get_all_views();
  foreach ($views as $view) {
    $viewnames[$view->name] = $view->name;
  }
  
  //load available view display types in to array for select lists
  $default_display = array('default' => 'Default');
  $other_displays = views_fetch_plugin_names('display');
  $displays = array_merge($default_display, $other_displays);
  
  //load available content types in to array for select list
  $content_types = array_keys(node_get_types());
  
  //load available ImageCache presets
  $fullpresets = imagecache_presets();
  foreach ($fullpresets as $preset) {
    $presets[$preset['presetname']] = $preset['presetname'] . ' ('.$preset['presetid'].')';
  }
  
  //content type selectors
  $form['content_types'] = array(
    '#type' => 'fieldset',
    '#title' => t('Content type selections'),
    '#description' => t('The module installs content types for you to use, but this interface allows you to select custom/different content types should you so wish.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['content_types']['gallery_content_type'] = array(
    '#type' => 'select',
    '#title' => t('Select the content type to use for galleries'),
    '#options' => $content_types,
    '#default_value' => array_search(variable_get('cck_gallery_gallery_type', 'cck_gallery'), $content_types),
  );
  $form['content_types']['image_content_type'] = array(
    '#type' => 'select',
    '#title' => t('Select the content type to use for images'),
    '#description' => t('Be aware this content type must have two CCK fields - field_image and field_gallery.'),
    '#options' => $content_types,
    '#default_value' => array_search(variable_get('cck_gallery_image_type', 'cck_image'), $content_types),
  );
  $form['content_types']['gallery_delete_options'] = array(
    '#type' => 'radios',
    '#title' => t('When a gallery is deleted'),
    '#options' => array('delete' => t('Delete associated image content'), 'user' => t('Allow the user to choose'), 'keep' => t('Keep associated image content')),
    '#default_value' => variable_get('cck_gallery_delete_options', 'user'),
  );
  //data purge options
  $form['content_types']['delete_content'] = array(
    '#type' => 'checkbox',
    '#title' => t('Delete all content of types specified above'),
    '#description' => t('USE WITH EXTREME CAUTION! Checking this box will DELETE, irrepairably, all node data when you click Save. Only use if you no longer want CCK Gallery.'),
  );
  
  //gallery view options
  $form['gallery_view'] = array(
    '#type' => 'fieldset',
    '#title' => t('Gallery view selection'),
    '#description' => t('The module provides a default view for galleries, which you may override in the database. You may also prefer to select a different view, using these settings.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['gallery_view']['gallery_default_view'] = array(
    '#type' => 'select',
    '#title' => t('Select the view to be used for displaying thumbnails in a gallery'),
    '#options' => $viewnames,
    '#default_value' => variable_get('cck_gallery_contents_view', 'gallery_contents'),
  );
  $form['gallery_view']['gallery_default_view_display'] = array(
    '#type' => 'select',
    '#title' => t('Select the display of the gallery view to be used'),
    '#options' => $displays,
    '#default_value' => variable_get('cck_gallery_contents_view_display', 'default'),
  );
  
  //user gallery list options
  $form['list_view'] = array(
    '#type' => 'fieldset',
    '#title' => t('Gallery list view selection'),
    '#description' => t('The module provides a default view for lists of galleries belonging to a user, which you may override in the database. You may also prefer to select a different view, using these settings.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['list_view']['gallery_default_list_view'] = array(
    '#type' => 'select',
    '#title' => t('Select the view to be used for displaying the list of user galleries'),
    '#options' => $viewnames,
    '#default_value' => variable_get('cck_gallery_list_view', 'gallery_list_page'),
  );
  $form['list_view']['gallery_default_list_view_display'] = array(
    '#type' => 'select',
    '#title' => t('Select the display of the gallery list to be used'),
    '#options' => $displays,
    '#default_value' => variable_get('cck_gallery_list_view_display', 'default'),
  );
  //gallery thumbnail selector views
  $form['list_view']['gallery_default_thumb_view'] = array(
    '#type' => 'select',
    '#title' => t('Select the view to be used for displaying the thumbnail for a gallery'),
    '#options' => $viewnames,
    '#default_value' => variable_get('cck_gallery_thumb_view', 'gallery_thumbnail'),
  );
  $form['list_view']['gallery_default_thumb_view_display'] = array(
    '#type' => 'select',
    '#title' => t('Select the display of the gallery thumbnail(s) to be used'),
    '#options' => $displays,
    '#default_value' => variable_get('cck_gallery_thumb_view_display', 'default'),
  );
  //thumbnails on/off
  $form['list_view']['gallery_thumb_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show gallery thumbnails on user gallery lists'),
    '#default_value' => variable_get('cck_gallery_enable_thumbs', 1),
  );
  //allow users to pick thumb option
  $form['list_view']['gallery_thumb_choose'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow users to select a thumbnail for their gallery by marking the image as "sticky"'),
    '#description' => t('Make sure you clear caches after enabling this option, as it alters a view which will be cached in the database.'),
    '#default_value' => variable_get('cck_gallery_sticky_thumbs', 0),
  );
  
  
  //imagecache prefered preset options
  $form['imagecache'] = array(
    '#type' => 'fieldset',
    '#title' => t('ImageCache presets'),
    '#description' => t('The module provides default ImageCache presets for thumbnails and full node views, but you can specify your own here.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['imagecache']['thumbnails'] = array(
    '#type' => 'select',
    '#title' => t('Select the ImageCache preset for thumbnails'),
    '#description' => t('IMPORTANT: You *must* clear caches after changing this. You change the preset for the full node preset using CCK on the image content type.'),
    '#options' => $presets,
    '#default_value' => variable_get('cck_gallery_imagecache_thumbs', 'thumbnail'),
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save configuration',
  );
  return $form;
}

function cck_gallery_admin_form_submit($form, &$form_state) {
  //purge CCK Gallery content
  if ($form['content_types']['delete_content']['#value'] == 1) {
    $result = db_query("SELECT nid FROM {node} WHERE type = '%s'", array('%s' => variable_get('cck_gallery_gallery_type', 'cck_gallery')));
    while ($thisnode = db_fetch_array($result)) {
      node_delete($thisnode['nid']);
    }
    $result = db_query("SELECT nid FROM {node} WHERE type = '%s'", array('%s' => variable_get('cck_gallery_image_type', 'cck_image')));
    while ($thisnode = db_fetch_array($result)) {
      node_delete($thisnode['nid']);
    }
    drupal_set_message(t('All CCK Gallery content has been purged. Note, the content types must be deleted manually.'));
  }
  
  //set content types
  variable_set('cck_gallery_gallery_type', $form['content_types']['gallery_content_type']['#options'][$form['content_types']['gallery_content_type']['#value']]);
  variable_set('cck_gallery_image_type', $form['content_types']['image_content_type']['#options'][$form['content_types']['image_content_type']['#value']]);
  variable_set('cck_gallery_delete_options', $form['content_types']['gallery_delete_options']['#value']);
  
  variable_set('cck_gallery_contents_view', $form['gallery_view']['gallery_default_view']['#value']);
  //TODO: we need to make sure the selected display exists in a validate funcion
  variable_set('cck_gallery_contents_view_display', $form['gallery_view']['gallery_default_view_display']['#value']);
  
  variable_set('cck_gallery_list_view', $form['list_view']['gallery_default_list_view']['#value']);
  //TODO: we need to make sure the selected display exists in a validate funcion
  variable_set('cck_gallery_list_view_display', $form['list_view']['gallery_default_list_view_display']['#value']);

  variable_set('cck_gallery_thumb_view', $form['list_view']['gallery_default_thumb_view']['#value']);
  //TODO: we need to make sure the selected display exists in a validate funcion
  variable_set('cck_gallery_thumb_view_display', $form['list_view']['gallery_default_thumb_view_display']['#value']);
  variable_set('cck_gallery_enable_thumbs', $form['list_view']['gallery_thumb_enabled']['#value']);
  variable_set('cck_gallery_sticky_thumbs', $form['list_view']['gallery_thumb_choose']['#value']);
  
  
  //save ImageCache presets
  variable_set('cck_gallery_imagecache_thumbs', $form['imagecache']['thumbnails']['#value']);
  
  drupal_set_message(t('Settings saved.'));
}